@@ -815,6 +815,9 @@ def get_gitlab_last_pipeline_id_by_branch(git_host, git_token, git_project_id, g
                            stream=True)
 
     if res.status_code == 200:
-        return json.loads(res.content)[0]['id']
+        if len(json.loads(res.content)) > 0:
+            return json.loads(res.content)[0]['id']
+        else:
+            return False
     else:
         raise Exception('pipeline id get failure %s %s' % (url, res.status_code))
